import { Observable } from 'rxjs';
import { mapTo, switchMap } from 'rxjs/operators';
import { unstable_cancelCallback as cancelCallback, unstable_scheduleCallback as scheduleCallback, unstable_forceFrameRate as forceFrameRate, } from 'scheduler/cjs/scheduler.production.min.js';
const NoPriority = 0;
const ImmediatePriority = 1;
const UserBlockingPriority = 2;
const NormalPriority = 3;
const LowPriority = 4;
const IdlePriority = 5;
forceFrameRate(16);
const ɵ0 = (cdRef) => cdRef.detectChanges(), ɵ1 = (work, scope) => {
    return (o$) => o$.pipe(scheduleOnQueue(work, { priority: NoPriority, scope }));
};
const noPriorityStrategy = {
    name: 'noPriority',
    work: ɵ0,
    behavior: ɵ1,
};
const ɵ2 = (cdRef) => cdRef.detectChanges(), ɵ3 = (work, scope) => {
    return (o$) => o$.pipe(scheduleOnQueue(work, {
        priority: ImmediatePriority,
        scope,
    }));
};
const immediateStrategy = {
    name: 'immediate',
    work: ɵ2,
    behavior: ɵ3,
};
const ɵ4 = (cdRef) => cdRef.detectChanges(), ɵ5 = (work, scope) => {
    return (o$) => o$.pipe(scheduleOnQueue(work, {
        priority: UserBlockingPriority,
        scope,
    }));
};
const userBlockingStrategy = {
    name: 'userBlocking',
    work: ɵ4,
    behavior: ɵ5,
};
const ɵ6 = (cdRef) => cdRef.detectChanges(), ɵ7 = (work, scope) => {
    return (o$) => o$.pipe(scheduleOnQueue(work, { priority: NormalPriority, scope }));
};
const normalStrategy = {
    name: 'normal',
    work: ɵ6,
    behavior: ɵ7,
};
const ɵ8 = (cdRef) => cdRef.detectChanges(), ɵ9 = (work, scope) => {
    return (o$) => o$.pipe(scheduleOnQueue(work, { priority: LowPriority, scope }));
};
const lowStrategy = {
    name: 'low',
    work: ɵ8,
    behavior: ɵ9,
};
const ɵ10 = (cdRef) => cdRef.detectChanges(), ɵ11 = (work, scope) => {
    return (o$) => o$.pipe(scheduleOnQueue(work, { priority: IdlePriority, scope }));
};
const idleStrategy = {
    name: 'idle',
    work: ɵ10,
    behavior: ɵ11,
};
function scheduleOnQueue(work, options) {
    return (o$) => o$.pipe(switchMap((v) => new Observable((subscriber) => {
        const task = scheduleCallback(options.priority, () => {
            work();
            subscriber.next(v);
        }, { delay: options.delay });
        return () => {
            cancelCallback(task);
        };
    }).pipe(mapTo(v))));
}
export const RX_CONCURRENT_STRATEGIES = {
    noPriority: noPriorityStrategy,
    immediate: immediateStrategy,
    userBlocking: userBlockingStrategy,
    normal: normalStrategy,
    low: lowStrategy,
    idle: idleStrategy,
};
export { ɵ0, ɵ1, ɵ2, ɵ3, ɵ4, ɵ5, ɵ6, ɵ7, ɵ8, ɵ9, ɵ10, ɵ11 };
//# sourceMappingURL=concurrent-strategies.js.map